summaryrefslogtreecommitdiff
path: root/include/xline.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/xline.h')
-rw-r--r--include/xline.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/xline.h b/include/xline.h
index d5dd87aa5..0fa6e3f53 100644
--- a/include/xline.h
+++ b/include/xline.h
@@ -424,11 +424,11 @@ class CoreExport XLineManager
*/
GLine* matches_gline(User* user);
/** Check if a IP matches a ZLine
* @param ipaddr The IP to check against
* @return The reason for the line if there is a match, or NULL if there is no match
*/
- ZLine* matches_zline(const char* ipaddr);
+ ZLine* matches_zline(User *user);
/** Check if a hostname matches a KLine
* @param user The user to check against
@@ -424,11 +424,11 @@ class CoreExport XLineManager
*/
GLine* matches_gline(User* user);
- /** Check if a IP matches a ZLine
- * @param ipaddr The IP to check against
+ /** Check if a user's IP matches a ZLine
+ * @param user The user to check against
* @return The reason for the line if there is a match, or NULL if there is no match
*/